@@ -3,10 +3,7 @@ require_relative 'test_helper'
 # Namespace entity tests
 class TestSecret < MiniTest::Test
   def test_get_secret_v1
-    stub_request(:get, %r{/api/v1$})
-      .to_return(body: open_test_file('core_api_resource_list.json'),
-                 status: 200)
-
+    stub_core_api_list
     stub_request(:get, %r{/secrets})
       .to_return(body: open_test_file('created_secret.json'),
                  status: 200)
@@ -26,10 +23,7 @@ class TestSecret < MiniTest::Test
   end
 
   def test_delete_secret_v1
-    stub_request(:get, %r{/api/v1$})
-      .to_return(body: open_test_file('core_api_resource_list.json'),
-                 status: 200)
-
+    stub_core_api_list
     stub_request(:delete, %r{/secrets})
       .to_return(status: 200, body: open_test_file('created_secret.json'))
 
@@ -43,10 +37,7 @@ class TestSecret < MiniTest::Test
   end
 
   def test_create_secret_v1
-    stub_request(:get, %r{/api/v1$})
-      .to_return(body: open_test_file('core_api_resource_list.json'),
-                 status: 200)
-
+    stub_core_api_list
     stub_request(:post, %r{/secrets})
       .to_return(body: open_test_file('created_secret.json'),
                  status: 201)
